@@ -35,27 +35,41 @@ jobWorkingDirectory=$1
 jobScratchDirectory=$2
 transferredTimestampFile=$3
 
-rm -rf ${jobWorkingDirectory}
-mkdir ${jobWorkingDirectory}
-exitStatus=$?
+sharedFileSystem=1
 
-if [ ${exitStatus} -eq 0 ] ; then
+if [ ${sharedFileSystem} -eq 1 ] ; then
    cd ${jobWorkingDirectory}
    exitStatus=$?
 
    if [ ${exitStatus} -eq 0 ] ; then
-      tar xvzf -
-      exitStatus=$?
-
-      if [ ${exitStatus} -eq 0 ] ; then
-         touch .__fileTimeMarker
-         sleep 1
-         date +"%s" > ${transferredTimestampFile}
-      fi
+      date +"%s" > ${transferredTimestampFile}
    fi
 
    mkdir -p ${jobScratchDirectory}
    exitStatus=$?
+else
+   rm -rf ${jobWorkingDirectory}
+   mkdir ${jobWorkingDirectory}
+   exitStatus=$?
+
+   if [ ${exitStatus} -eq 0 ] ; then
+      cd ${jobWorkingDirectory}
+      exitStatus=$?
+
+      if [ ${exitStatus} -eq 0 ] ; then
+         tar xvzf -
+         exitStatus=$?
+
+         if [ ${exitStatus} -eq 0 ] ; then
+            touch .__fileTimeMarker
+            sleep 1
+            date +"%s" > ${transferredTimestampFile}
+         fi
+      fi
+
+      mkdir -p ${jobScratchDirectory}
+      exitStatus=$?
+   fi
 fi
 
 exit ${exitStatus}
